@@ -29,6 +29,8 @@ import android.support.annotation.Nullable;
 import android.util.Log;
 
 import com.coremedia.iso.boxes.Container;
+import com.facebook.react.bridge.ReadableMap;
+import com.facebook.react.uimanager.ThemedReactContext;
 import com.googlecode.mp4parser.FileDataSourceViaHeapImpl;
 import com.googlecode.mp4parser.authoring.Movie;
 import com.googlecode.mp4parser.authoring.Track;
@@ -49,18 +51,21 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 
+import com.shahenlibrary.Trimmer.Trimmer;
+import com.shahenlibrary.interfaces.OnCompressVideoListener;
 import com.shahenlibrary.interfaces.OnTrimVideoListener;
 
+
 public class VideoEdit {
 
   private static final String TAG = "RNVideoEdit";
 
   public static boolean shouldUseURI(@Nullable String path) {
     String[] supportedProtocols = {
-      "content://",
-      "file://",
-      "http://",
-      "https://"
+            "content://",
+            "file://",
+            "http://",
+            "https://"
     };
     if (path == null) {
       return false;
@@ -88,6 +93,10 @@ public class VideoEdit {
     genVideoUsingMp4Parser(src, file, startMs, endMs, callback);
   }
 
+  public static void startCompress(@NonNull String source, @NonNull final OnCompressVideoListener callback, ThemedReactContext ctx, ReadableMap options) throws IOException {
+    Trimmer.compress(source, options, null, callback, ctx, null);
+  }
+
   private static void genVideoUsingMp4Parser(@NonNull File src, @NonNull File dst, long startMs, long endMs, @NonNull OnTrimVideoListener callback) throws IOException {
     if (!src.exists()) {
       String error = "Targeted video is not found";
