@@ -10,11 +10,12 @@ import Foundation
 
 @objc(RNVideoProcessingManager)
 class RNVideoProcessingManager: RCTViewManager {
-    
-    @objc override func view() -> UIView! {
-        return RNVideoPlayer()
-    }
-    override func constantsToExport() -> [String : Any]! {
+
+   @objc override func view() -> UIView! {
+       return RNVideoPlayer()
+   }
+
+    @objc override func constantsToExport() -> [AnyHashable: Any] {
         return [
             "ScaleNone": AVLayerVideoGravityResizeAspect,
             "ScaleToFill": AVLayerVideoGravityResize,
@@ -22,4 +23,8 @@ class RNVideoProcessingManager: RCTViewManager {
             "ScaleAspectFill": AVLayerVideoGravityResizeAspectFill
         ]
     }
+
+    override class func requiresMainQueueSetup() -> Bool {
+        return true
+    }
 }
