@@ -12,7 +12,7 @@ import type {
 import { getActualSource } from '../utils';
 
 const { RNTrimmerManager: TrimmerManager } = NativeModules;
-class ProcessingManager {
+export class ProcessingManager {
   static trim(source: sourceType, options: trimOptions): Promise<string> {
     const actualSource: string = getActualSource(source);
     const mData = { source: actualSource, ...options };
@@ -49,5 +49,3 @@ class ProcessingManager {
   }
 
 }
-
-export default ProcessingManager;
