@@ -1,4 +1,5 @@
-import React, { Component, PropTypes } from 'react';
+import React, { Component } from 'react';
+import PropTypes from 'prop-types';
 import { noop } from 'lodash';
 import {
   AppRegistry,
@@ -8,7 +9,8 @@ import {
   requireNativeComponent,
   CameraRoll,
   UIManager,
-  findNodeHandle
+  findNodeHandle,
+  ViewPropTypes
 } from 'react-native';
 import { getActualSource } from '../utils';
 
@@ -24,7 +26,7 @@ export class VideoPlayer extends Component {
     }
   };
   static propTypes = {
-    ...View.propTypes,
+    ...ViewPropTypes,
     play: PropTypes.bool,
     replay: PropTypes.bool,
     volume: PropTypes.number,
